##  What Are the Benefits of Application Rationalization?
Here are some facts and figures on how companies can benefit from application rationalization, based on SAP LeanIX customer experiences and research:
  * Decommissioning 10% of all applications within 12 months, read more in [the customer success story![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Fmediamarktsaturn-technology "https://www.leanix.net/en/customers/success-stories/mediamarktsaturn-technology").
  * Identified opportunities to reduce the application landscape by 25%, read more in [the customer success story![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Ffab "https://www.leanix.net/en/customers/success-stories/fab").
  * Average of 5 months SAP LeanIX payback period, read more in [the IDC whitepaper![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fthe-business-value-of-sap-leanix "https://www.leanix.net/en/download/the-business-value-of-sap-leanix").
